==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-attachments/dictionaries/de.dict.itop-attachments.php <==
<?php
// Copyright (C) 2010-2023 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/*
* @author ITOMIG GmbH <martin.raenker@itomig.de>

* @copyright     Copyright (C) 2023 Combodo SARL
* @licence	http://opensource.org/licenses/AGPL-3.0
*		
*/
Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Attachments:TabTitle_Count' => 'Attachments (%1$d)',
	'Attachments:EmptyTabTitle' => 'Attachments',
	'Attachments:FieldsetTitle' => 'Attachments',
	'Attachments:DeleteBtn' => 'Löschen',
	'Attachments:History_File_Added' => 'Attachment %1$s hinzugefügt.',
	'Attachments:History_File_Removed' => 'Attachment %1$s entfernt.',
	'Attachments:AddAttachment' => 'Attachment hinzufügen: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Dateiupload in diesem System NICHT erlaubt',
	'Attachment:Max_Go' => '(Maximale Dateigröße: %1$s GB)',
	'Attachment:Max_Mo' => '(Maximale Dateigröße: %1$s MB)',
	'Attachment:Max_Ko' => '(Maximale Dateigröße: %1$s KB)',
	'Attachments:NoAttachment' => 'Kein Attachment',
	'Attachments:PreviewNotAvailable' => 'Vorschau für diesen Attachment-Typ nicht verfügbar',
	'Attachments:Error:FileTooLarge' => 'Die Datei ist zu groß für den Upload: %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Die Datei ist leer und kann nicht angehängt werden.
Entweder ist die von Ihnen hochdeladene Datei leer,
oder melden Sie dem '.ITOP_APPLICATION_SHORT.' Administrator diesen Fehler, weil eventuell kein ausreichender Speicherplatz zur Verfügung steht',
	'Attachments:Render:Icons' => 'Als Icons anzeigen',
	'Attachments:Render:Table' => 'Als Liste anzeigen',
	'UI:Attachments:DropYourFileHint' => 'Dateien in diesem Bereich ablegen...',
));

//
// Class: Attachment
//

Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:Attachment' => 'Attachment',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:expire' => 'Läuft ab',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Temporäre ID',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:item_class' => 'Itemklasse',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Item Organisation',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Inhalt',
	'Class:Attachment/Attribute:contents+' => '',
));


Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Attachments:File:Thumbnail' => 'Icon',
	'Attachments:File:Name' => 'Dateiname',
	'Attachments:File:Date' => 'Upload-Datum',
	'Attachments:File:Uploader' => 'hochgeladen von',
	'Attachments:File:Size' => 'Größe',
	'Attachments:File:MimeType' => 'Typ',
	'Attachments:File:DownloadsCount' => 'Downloads',
));
//
// Class: Attachment
//

Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:Attachment/Attribute:creation_date' => 'Erstellungsdatum',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:user_id' => 'Benutzer ID',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Kontakt ID',
	'Class:Attachment/Attribute:contact_id+' => '',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:TriggerOnAttachmentDownload' => 'Trigger (beim Herunterladen eines Attachment eines Objekts)',
	'Class:TriggerOnAttachmentDownload+' => 'Trigger für das Herunterladen des Attachments der angegebenen Klasse oder einer Unterklasse',
));

==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-attachments/dictionaries/de.dict.itop-attachments.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author ITOMIG GmbH <martin.raenker@itomig.de>
 *
 */
Dict::Add('DE DE', 'German', 'Deutsch', [
	'Attachment:Max_Go' => '(Maximale Dateigröße: %1$s GB)',
	'Attachment:Max_Ko' => '(Maximale Dateigröße: %1$s KB)',
	'Attachment:Max_Mo' => '(Maximale Dateigröße: %1$s MB)',
	'Attachments:AddAttachment' => 'Attachment hinzufügen: ',
	'Attachments:DeleteBtn' => 'Löschen',
	'Attachments:EmptyTabTitle' => 'Attachments',
	'Attachments:Error:FileTooLarge' => 'Die Datei ist zu groß für den Upload: %1$s',
	'Attachments:Error:UploadedFileEmpty' => 'Die Datei ist leer und kann nicht angehängt werden.
Entweder ist die von Ihnen hochdeladene Datei leer,
oder melden Sie dem '.ITOP_APPLICATION_SHORT.' Administrator diesen Fehler, weil eventuell kein ausreichender Speicherplatz zur Verfügung steht',
	'Attachments:FieldsetTitle' => 'Attachments',
	'Attachments:File:Date' => 'Upload-Datum',
	'Attachments:File:DownloadsCount' => 'Downloads',
	'Attachments:File:MimeType' => 'Typ',
	'Attachments:File:Name' => 'Dateiname',
	'Attachments:File:Size' => 'Größe',
	'Attachments:File:Thumbnail' => 'Icon',
	'Attachments:File:Uploader' => 'hochgeladen von',
	'Attachments:History_File_Added' => 'Attachment %1$s hinzugefügt.',
	'Attachments:History_File_Removed' => 'Attachment %1$s entfernt.',
	'Attachments:NoAttachment' => 'Kein Attachment',
	'Attachments:PreviewNotAvailable' => 'Vorschau für diesen Attachment-Typ nicht verfügbar',
	'Attachments:Render:Icons' => 'Als Icons anzeigen',
	'Attachments:Render:Table' => 'Als Liste anzeigen',
	'Attachments:TabTitle_Count' => 'Attachments (%1$d)',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Dateiupload in diesem System NICHT erlaubt',
	'Class:Attachment' => 'Attachment',
	'Class:Attachment+' => '',
	'Class:Attachment/Attribute:contact_id' => 'Kontakt ID',
	'Class:Attachment/Attribute:contact_id+' => '',
	'Class:Attachment/Attribute:contents' => 'Inhalt',
	'Class:Attachment/Attribute:contents+' => '',
	'Class:Attachment/Attribute:creation_date' => 'Erstellungsdatum',
	'Class:Attachment/Attribute:creation_date+' => '',
	'Class:Attachment/Attribute:expire' => 'Läuft ab',
	'Class:Attachment/Attribute:expire+' => '',
	'Class:Attachment/Attribute:item_class' => 'Itemklasse',
	'Class:Attachment/Attribute:item_class+' => '',
	'Class:Attachment/Attribute:item_id' => 'Item',
	'Class:Attachment/Attribute:item_id+' => '',
	'Class:Attachment/Attribute:item_org_id' => 'Item Organisation',
	'Class:Attachment/Attribute:item_org_id+' => '',
	'Class:Attachment/Attribute:temp_id' => 'Temporäre ID',
	'Class:Attachment/Attribute:temp_id+' => '',
	'Class:Attachment/Attribute:user_id' => 'Benutzer ID',
	'Class:Attachment/Attribute:user_id+' => '',
	'Class:TriggerOnAttachmentDownload' => 'Trigger (beim Herunterladen eines Attachment eines Objekts)',
	'Class:TriggerOnAttachmentDownload+' => 'Trigger für das Herunterladen des Attachments der angegebenen Klasse oder einer Unterklasse',
	'UI:Attachments:DropYourFileHint' => 'Dateien in diesem Bereich ablegen...',
]);
